Garfield.nn.DSBatchNorm
=======================

.. currentmodule:: Garfield.nn

.. autoclass:: DSBatchNorm

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DSBatchNorm.__init__
      ~DSBatchNorm.add_module
      ~DSBatchNorm.apply
      ~DSBatchNorm.bfloat16
      ~DSBatchNorm.buffers
      ~DSBatchNorm.children
      ~DSBatchNorm.compile
      ~DSBatchNorm.cpu
      ~DSBatchNorm.cuda
      ~DSBatchNorm.double
      ~DSBatchNorm.eval
      ~DSBatchNorm.extra_repr
      ~DSBatchNorm.float
      ~DSBatchNorm.forward
      ~DSBatchNorm.get_buffer
      ~DSBatchNorm.get_extra_state
      ~DSBatchNorm.get_parameter
      ~DSBatchNorm.get_submodule
      ~DSBatchNorm.half
      ~DSBatchNorm.ipu
      ~DSBatchNorm.load_state_dict
      ~DSBatchNorm.modules
      ~DSBatchNorm.named_buffers
      ~DSBatchNorm.named_children
      ~DSBatchNorm.named_modules
      ~DSBatchNorm.named_parameters
      ~DSBatchNorm.parameters
      ~DSBatchNorm.register_backward_hook
      ~DSBatchNorm.register_buffer
      ~DSBatchNorm.register_forward_hook
      ~DSBatchNorm.register_forward_pre_hook
      ~DSBatchNorm.register_full_backward_hook
      ~DSBatchNorm.register_full_backward_pre_hook
      ~DSBatchNorm.register_load_state_dict_post_hook
      ~DSBatchNorm.register_module
      ~DSBatchNorm.register_parameter
      ~DSBatchNorm.register_state_dict_pre_hook
      ~DSBatchNorm.requires_grad_
      ~DSBatchNorm.reset_parameters
      ~DSBatchNorm.reset_running_stats
      ~DSBatchNorm.set_extra_state
      ~DSBatchNorm.share_memory
      ~DSBatchNorm.state_dict
      ~DSBatchNorm.to
      ~DSBatchNorm.to_empty
      ~DSBatchNorm.train
      ~DSBatchNorm.type
      ~DSBatchNorm.xpu
      ~DSBatchNorm.zero_grad
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DSBatchNorm.T_destination
      ~DSBatchNorm.call_super_init
      ~DSBatchNorm.dump_patches
      ~DSBatchNorm.training
   
   